FormulaArg

Struct FormulaArg 

pub struct FormulaArg {
    pub sheet_name: String,
    pub number: f64,
    pub string: String,
    pub list: Vec<FormulaArg>,
    pub matrix: Vec<Vec<FormulaArg>>,
    pub boolean: bool,
    pub error: String,
    pub cell_refs: Vec<CellRef>,
    pub cell_ranges: Vec<(CellRef, CellRef)>,
    pub typ: ArgType,
}
A single formula argument, value, or result.

Fields

sheet_name: Stringnumber: f64string: Stringlist: Vec<FormulaArg>matrix: Vec<Vec<FormulaArg>>boolean: boolerror: Stringcell_refs: Vec<CellRef>cell_ranges: Vec<(CellRef, CellRef)>typ: ArgType

Implementations

Source

impl FormulaArg

pub fn value(&self) -> String

Return the Excel textual representation of this argument.

pub fn to_number(&self) -> FormulaArg

Convert the argument to a number argument, returning #VALUE! on failure.

pub fn to_bool(&self) -> FormulaArg

Convert the argument to a boolean argument.

pub fn to_list(&self) -> Vec<FormulaArg>

Flatten a matrix/list/number/string/error to a one-dimensional list.

pub fn as_number(&self) -> Option<f64>

Try to interpret the argument as a number.

pub fn as_bool(&self) -> bool

Interpret the argument as a boolean.

pub fn as_string(&self) -> String

Convert the argument to its string representation.

pub fn is_error(&self) -> bool

Return true if this argument represents an Excel error.