pub fn first_error(args: &[FormulaArg]) -> Option<FormulaArg>Expand description
Return the first error found in a slice of arguments, if any.
pub fn first_error(args: &[FormulaArg]) -> Option<FormulaArg>Return the first error found in a slice of arguments, if any.