pub enum CellValue {
String(String),
Int(i64),
Float(f64),
Bool(bool),
Formula(String),
DateTime(NaiveDateTime),
Date(NaiveDate),
Time(NaiveTime),
Duration(Duration),
RichText(Vec<RichTextRun>),
}Expand description
Value that can be written to a worksheet cell.
Variants
String(String)
Plain text or string value.
Int(i64)
Integer value.
Float(f64)
Floating point value.
Bool(bool)
Boolean value.
Formula(String)
Formula string (without leading =).
DateTime(NaiveDateTime)
Date/time value.
Date(NaiveDate)
Date value.
Time(NaiveTime)
Time value.
Duration(Duration)
Time duration stored as a fraction of a day.
RichText(Vec<RichTextRun>)
Rich text runs.