Module crypt

Module crypt 

Workbook encryption / decryption (crypt.go).

Provides ECMA-376 agile and standard encryption helpers, CFB packaging and the ISO password hashing algorithm used for sheet/workbook protection.

Structs

DataIntegrity
Encrypted copies of the salt/hash values used for integrity checks.
EncryptedKey
Encrypted key used to derive the package encryption key.
Encryption
Top-level encryption info container used by ECMA-376 agile encryption.
KeyData
Cryptographic attributes used to encrypt the data.
KeyEncryptor
A single key encryptor entry.
KeyEncryptors
Collection of key encryptors.
StandardEncryptionHeader
StandardEncryptionVerifier

Functions

decrypt
Decrypt a CFB-encoded workbook package.
encrypt
Encrypt a workbook package with a password using ECMA-376 standard encryption (AES-128).
gen_iso_passwd_hash
Generate an ISO password hash, salt and hash value.