Document properties API (docProps.go).
Provides read/write access to the application, core and custom document
properties stored in docProps/app.xml, docProps/core.xml and
docProps/custom.xml.
Document properties API (docProps.go).
Provides read/write access to the application, core and custom document
properties stored in docProps/app.xml, docProps/core.xml and
docProps/custom.xml.