Module errors

Module errors 

Error types and messages for the excelize crate.

These errors are ported from the Go excelize package’s errors.go.

Structs

ErrAddVBAProject
ErrAttrValBool
ErrCellCharsLength
ErrCellStyles
ErrChartTitle
ErrColumnNumber
ErrColumnWidth
ErrCoordinates
ErrCustomNumFmt
ErrDataValidationFormulaLength
ErrDataValidationRange
ErrDefinedNameDuplicate
ErrDefinedNameScope
ErrExistsSheet
ErrExistsTableName
ErrFillGradientColor
ErrFillGradientShading
ErrFillPattern
ErrFillPatternColor
ErrFillType
ErrFontLength
ErrFontSize
ErrFormControlValue
ErrGroupSheets
ErrImgExt
ErrImgLoad
ErrInvalidDate
ErrInvalidFormula
ErrMaxFilePathLength
ErrMaxGraphicAltTextLength
ErrMaxGraphicNameLength
ErrMaxRowHeight
ErrMaxRows
ErrNameLength
ErrOptionsUnzipSizeLimit
ErrOutlineLevel
ErrPageSetupAdjustTo
ErrParameterInvalid
ErrParameterRequired
ErrPasswordLengthInvalid
ErrPivotTableClassicLayout
ErrPivotTableShowValuesAsBaseField
ErrPivotTableShowValuesAsBaseItem
ErrSave
ErrSheetIdx
ErrSheetNameBlank
ErrSheetNameInvalid
ErrSheetNameLength
ErrSheetNameSingleQuote
ErrSheetNotExist
Error returned when a worksheet does not exist.
ErrSparkline
ErrSparklineLocation
ErrSparklineRange
ErrSparklineStyle
ErrSparklineType
ErrTotalSheetHyperlinks
ErrTransparency
ErrUnknownEncryptMechanism
ErrUnprotectSheet
ErrUnprotectSheetPassword
ErrUnprotectWorkbook
ErrUnprotectWorkbookPassword
ErrUnsupportedEncryptMechanism
ErrUnsupportedHashAlgorithm
ErrUnsupportedNumberFormat
ErrUnsupportedPivotTableShowValuesAsType
ErrWorkbook
ErrWorkbookFileFormat
ErrWorkbookPassword

Functions

new_add_comment_error
new_cell_name_to_coordinates_error
new_chart_title_error
new_coordinates_to_cell_name_error
new_field_length_error
new_invalid_auto_filter_column_error
new_invalid_auto_filter_exp_error
new_invalid_auto_filter_operator_error
new_invalid_cell_name_error
new_invalid_column_name_error
new_invalid_excel_date_error
new_invalid_link_type_error
new_invalid_name_error
new_invalid_optional_value
new_invalid_row_number_error
new_invalid_shared_string_index_error
new_invalid_slicer_name_error
new_invalid_style_id_error
new_no_exist_slicer_error
new_no_exist_table_error
new_not_worksheet_error
new_pivot_table_col_fields_error
new_pivot_table_data_range_error
new_pivot_table_range_error
new_pivot_table_row_fields_error
new_pivot_table_selected_item_error
new_pivot_table_show_values_as_base_field_error
new_stream_set_row_error
new_stream_set_row_order_error
new_unknown_filter_token_error
new_unsupported_chart_type_error
new_unsupported_pivot_cache_source_type_error
new_unzip_size_limit_error
new_view_idx_error

Type Aliases

Result
A convenience alias for a Result using the dynamic Error type.