pub struct SlicerOptions {
pub name: String,
pub cell: String,
pub table_sheet: String,
pub table_name: String,
pub caption: String,
pub macro_name: String,
pub width: i32,
pub height: i32,
pub display_header: Option<bool>,
pub item_desc: bool,
pub format: GraphicOptions,
pub selected_items: Vec<String>,
/* private fields */
}Expand description
Slicer creation and read-back options.
Fields
name: StringName specifies the slicer name, should be an existing field name of the given table or pivot table.
cell: StringCell specifies the left top cell coordinates for inserting the slicer.
table_sheet: StringTableSheet specifies the worksheet name of the table or pivot table.
table_name: StringTableName specifies the name of the table or pivot table.
caption: StringCaption specifies the caption of the slicer.
macro_name: StringMacro used for set macro for the slicer.
width: i32Width specifies the width of the slicer.
height: i32Height specifies the height of the slicer.
display_header: Option<bool>DisplayHeader specifies if display header of the slicer.
item_desc: boolItemDesc specifies descending (Z-A) item sorting.
format: GraphicOptionsFormat specifies the format of the slicer.
selected_items: Vec<String>SelectedItems option is used to specify the default selected items.