pub struct StreamWriter<'a> { /* private fields */ }Expand description
Streaming writer for worksheets with large amounts of data.
Implementations
Sourceimpl<'a> StreamWriter<'a>
impl<'a> StreamWriter<'a>
Sourcepub fn new(file: &'a File, sheet: &str) -> Result<Self>
pub fn new(file: &'a File, sheet: &str) -> Result<Self>
Create a new stream writer for the given worksheet.
Sourcepub fn add_table(&mut self, table: &TableOptions) -> Result<()>
pub fn add_table(&mut self, table: &TableOptions) -> Result<()>
Add a table within the streamed sheet.
Sourcepub fn set_row(
&mut self,
cell: &str,
values: &[&dyn StreamCellValue],
opts: Option<RowOpts>,
) -> Result<()>
pub fn set_row( &mut self, cell: &str, values: &[&dyn StreamCellValue], opts: Option<RowOpts>, ) -> Result<()>
Write a row of values starting at cell.
Values may be any type implementing StreamCellValue. Mixed types can
be passed as &[&dyn StreamCellValue] to match Go’s []interface{}.
Row options are optional and default to RowOpts::default when None.
Sourcepub fn set_col_visible(
&mut self,
min_val: i32,
max_val: i32,
visible: bool,
) -> Result<()>
pub fn set_col_visible( &mut self, min_val: i32, max_val: i32, visible: bool, ) -> Result<()>
Set column visibility for a range of columns.
Sourcepub fn set_col_outline_level(&mut self, col: i32, level: u8) -> Result<()>
pub fn set_col_outline_level(&mut self, col: i32, level: u8) -> Result<()>
Set the outline level for a column.
Sourcepub fn set_col_style(
&mut self,
min_val: i32,
max_val: i32,
style_id: i32,
) -> Result<()>
pub fn set_col_style( &mut self, min_val: i32, max_val: i32, style_id: i32, ) -> Result<()>
Set the style for a range of columns.
Sourcepub fn set_col_width(
&mut self,
min_val: i32,
max_val: i32,
width: f64,
) -> Result<()>
pub fn set_col_width( &mut self, min_val: i32, max_val: i32, width: f64, ) -> Result<()>
Set the width for a range of columns.
Sourcepub fn insert_page_break(&mut self, cell: &str) -> Result<()>
pub fn insert_page_break(&mut self, cell: &str) -> Result<()>
Insert a page break at the given cell.