Module app

Module app 

Extended document properties (docProps/app.xml).

Ported from Go xmlApp.go.

Structs

AppProperties
Directly maps the document application properties.
XlsxDigSig
Contains the signature of a digitally signed document.
XlsxProperties
OOXML document properties such as the template used, the number of pages and words, and the application name and version.
XlsxVectorLpstr
XlsxVectorVariant
Specifies the set of hyperlinks that were in the document when last saved.