pub struct XlsxProperties {Show 28 fields
pub vt: Option<String>,
pub template: Option<String>,
pub manager: Option<String>,
pub company: Option<String>,
pub pages: Option<i64>,
pub words: Option<i64>,
pub characters: Option<i64>,
pub presentation_format: Option<String>,
pub lines: Option<i64>,
pub paragraphs: Option<i64>,
pub slides: Option<i64>,
pub notes: Option<i64>,
pub total_time: Option<i64>,
pub hidden_slides: Option<i64>,
pub mm_clips: Option<i64>,
pub scale_crop: Option<bool>,
pub heading_pairs: Option<XlsxVectorVariant>,
pub titles_of_parts: Option<XlsxVectorLpstr>,
pub links_up_to_date: Option<bool>,
pub characters_with_spaces: Option<i64>,
pub shared_doc: Option<bool>,
pub hyperlink_base: Option<String>,
pub h_links: Option<XlsxVectorVariant>,
pub hyperlinks_changed: Option<bool>,
pub dig_sig: Option<XlsxDigSig>,
pub application: Option<String>,
pub app_version: Option<String>,
pub doc_security: Option<i64>,
}Expand description
OOXML document properties such as the template used, the number of pages and words, and the application name and version.
Fields
vt: Option<String>template: Option<String>manager: Option<String>company: Option<String>pages: Option<i64>words: Option<i64>characters: Option<i64>presentation_format: Option<String>lines: Option<i64>paragraphs: Option<i64>slides: Option<i64>notes: Option<i64>total_time: Option<i64>mm_clips: Option<i64>scale_crop: Option<bool>heading_pairs: Option<XlsxVectorVariant>titles_of_parts: Option<XlsxVectorLpstr>links_up_to_date: Option<bool>characters_with_spaces: Option<i64>hyperlink_base: Option<String>h_links: Option<XlsxVectorVariant>hyperlinks_changed: Option<bool>dig_sig: Option<XlsxDigSig>application: Option<String>app_version: Option<String>doc_security: Option<i64>Trait Implementations
Sourceimpl Clone for XlsxProperties
impl Clone for XlsxProperties
Sourcefn clone(&self) -> XlsxProperties
fn clone(&self) -> XlsxProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxProperties
impl Debug for XlsxProperties
Sourceimpl Default for XlsxProperties
impl Default for XlsxProperties
Sourcefn default() -> XlsxProperties
fn default() -> XlsxProperties
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxProperties
impl<'de> Deserialize<'de> for XlsxProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxProperties
impl PartialEq for XlsxProperties
Sourceimpl Serialize for XlsxProperties
impl Serialize for XlsxProperties
impl StructuralPartialEq for XlsxProperties