pub struct CDLbls {
pub num_fmt: Option<CNumFmt>,
pub sp_pr: Option<CSpPr>,
pub tx_pr: Option<CTxPr>,
pub d_lbl_pos: Option<AttrValString>,
pub show_legend_key: Option<AttrValBool>,
pub show_val: Option<AttrValBool>,
pub show_cat_name: Option<AttrValBool>,
pub show_ser_name: Option<AttrValBool>,
pub show_percent: Option<AttrValBool>,
pub show_bubble_size: Option<AttrValBool>,
pub show_leader_lines: Option<AttrValBool>,
}Expand description
Directly maps the dLbls element. This element serves as a root element that specifies the settings for the data labels for an entire series or the entire chart.
Fields
num_fmt: Option<CNumFmt>sp_pr: Option<CSpPr>tx_pr: Option<CTxPr>d_lbl_pos: Option<AttrValString>show_legend_key: Option<AttrValBool>show_val: Option<AttrValBool>show_cat_name: Option<AttrValBool>show_ser_name: Option<AttrValBool>show_percent: Option<AttrValBool>show_bubble_size: Option<AttrValBool>show_leader_lines: Option<AttrValBool>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CDLbls
impl<'de> Deserialize<'de> for CDLbls
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for CDLbls