XlsxChartSpace

Struct XlsxChartSpace 

pub struct XlsxChartSpace {
    pub xmlns_c: Option<String>,
    pub xmlns_a: Option<String>,
    pub date_1904: Option<AttrValBool>,
    pub lang: Option<AttrValString>,
    pub rounded_corners: Option<AttrValBool>,
    pub chart: CChart,
    pub sp_pr: Option<CSpPr>,
    pub tx_pr: Option<CTxPr>,
    pub print_settings: Option<CPrintSettings>,
}
Directly maps the chartSpace element. The chart namespace in DrawingML is for representing visualizations of numeric data with column charts, pie charts, scatter charts, or other types of charts.

Fields

xmlns_c: Option<String>xmlns_a: Option<String>date_1904: Option<AttrValBool>lang: Option<AttrValString>rounded_corners: Option<AttrValBool>chart: CChartsp_pr: Option<CSpPr>tx_pr: Option<CTxPr>print_settings: Option<CPrintSettings>