Module chart_sheet

Module chart_sheet 

Chartsheet part (chartsheets/sheet*.xml).

Ported from Go xmlChartSheet.go.

Structs

XlsxChartsheet
Directly maps the chartsheet element of Chartsheet Parts in a SpreadsheetML document.
XlsxChartsheetPr
Specifies chart sheet properties.
XlsxChartsheetProtection
Expresses the chart sheet protection options to enforce when the chart sheet is protected.
XlsxChartsheetView
Defines custom view properties for chart sheets.
XlsxChartsheetViews
Specifies chart sheet views.
XlsxCustomChartsheetView
Defines custom view properties for chart sheets.
XlsxCustomChartsheetViews
Collection of custom Chart Sheet View information.
XlsxDrawing
Drawing reference for a chartsheet.
XlsxDrawingHF
Drawing reference in header/footer.
XlsxHeaderFooter
When printed or viewed in page layout view, each page of a worksheet can have a page header, a page footer, or both.
XlsxPageMargins
Page margins for a sheet or a custom sheet view.
XlsxPageSetUp
Page setup settings for the worksheet.
XlsxPicture
Picture reference for a chartsheet.