pub struct XlsxTypes {
pub xmlns: Option<String>,
pub entries: Vec<XlsxContentTypeEntry>,
}Expand description
Directly maps the Types element of the content types part.
Fields
xmlns: Option<String>entries: Vec<XlsxContentTypeEntry>Mixed Default and Override entries under the root Types element.
Implementations
Sourceimpl XlsxTypes
impl XlsxTypes
Sourcepub fn defaults(&self) -> Vec<XlsxDefault>
pub fn defaults(&self) -> Vec<XlsxDefault>
Return all Default entries.
Sourcepub fn overrides(&self) -> Vec<XlsxOverride>
pub fn overrides(&self) -> Vec<XlsxOverride>
Return all Override entries.
Sourcepub fn entries_mut(&mut self) -> &mut Vec<XlsxContentTypeEntry>
pub fn entries_mut(&mut self) -> &mut Vec<XlsxContentTypeEntry>
Iterate over entries mutably.