Module custom

Module custom 

Custom file properties part (docProps/custom.xml).

Ported from Go xmlCustom.go.

Structs

CustomProperty
Directly maps the custom property of the workbook. The value date type may be one of the following: int32, float64, string, bool, time.Time, or nil.
DecodeCustomProperties
Deserialization-only representation of the custom file properties part.
DecodeProperty
Deserialization-only representation of a single custom file property.
XlsxCustomProperties
Directly maps the element for the custom file properties part, that represents additional information. The information can be used as metadata for XML.
XlsxProperty
Directly maps the element specifies a single custom file property. Custom file property type is defined through child elements in the File Properties Variant Type namespace. Custom file property value can be set by setting the appropriate Variant Type child element value.

Enums

CustomPropertyValue
Value types that can be stored in a custom property.