pub struct XlsxCustomProperties {
pub xmlns: Option<String>,
pub vt: Option<String>,
pub property: Vec<XlsxProperty>,
}Expand description
Directly maps the element for the custom file properties part, that represents additional information. The information can be used as metadata for XML.
Fields
xmlns: Option<String>vt: Option<String>property: Vec<XlsxProperty>Trait Implementations
Sourceimpl Clone for XlsxCustomProperties
impl Clone for XlsxCustomProperties
Sourcefn clone(&self) -> XlsxCustomProperties
fn clone(&self) -> XlsxCustomProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxCustomProperties
impl Debug for XlsxCustomProperties
Sourceimpl Default for XlsxCustomProperties
impl Default for XlsxCustomProperties
Sourcefn default() -> XlsxCustomProperties
fn default() -> XlsxCustomProperties
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxCustomProperties
impl<'de> Deserialize<'de> for XlsxCustomProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxCustomProperties
impl PartialEq for XlsxCustomProperties
Sourceimpl Serialize for XlsxCustomProperties
impl Serialize for XlsxCustomProperties
impl StructuralPartialEq for XlsxCustomProperties