XlsxProperty

Struct XlsxProperty 

pub struct XlsxProperty {
Show 37 fields pub fmt_id: String, pub pid: i64, pub name: Option<String>, pub link_target: Option<String>, pub vector: Option<String>, pub array: Option<String>, pub blob: Option<String>, pub oblob: Option<String>, pub empty: Option<String>, pub null: Option<String>, pub i1: Option<i8>, pub i2: Option<i16>, pub i4: Option<i32>, pub i8: Option<i64>, pub int: Option<i64>, pub ui1: Option<u8>, pub ui2: Option<u16>, pub ui4: Option<u32>, pub ui8: Option<u64>, pub uint: Option<u64>, pub r4: Option<f32>, pub r8: Option<f64>, pub decimal: Option<String>, pub lpstr: Option<String>, pub lpwstr: Option<String>, pub bstr: Option<String>, pub date: Option<String>, pub file_time: Option<String>, pub bool: Option<bool>, pub cy: Option<String>, pub error: Option<String>, pub stream: Option<String>, pub ostream: Option<String>, pub storage: Option<String>, pub ostorage: Option<String>, pub vstream: Option<String>, pub cls_id: Option<String>,
}
Directly maps the element specifies a single custom file property. Custom file property type is defined through child elements in the File Properties Variant Type namespace. Custom file property value can be set by setting the appropriate Variant Type child element value.

Fields

fmt_id: Stringpid: i64name: Option<String>link_target: Option<String>vector: Option<String>array: Option<String>blob: Option<String>oblob: Option<String>empty: Option<String>null: Option<String>i1: Option<i8>i2: Option<i16>i4: Option<i32>i8: Option<i64>int: Option<i64>ui1: Option<u8>ui2: Option<u16>ui4: Option<u32>ui8: Option<u64>uint: Option<u64>r4: Option<f32>r8: Option<f64>decimal: Option<String>lpstr: Option<String>lpwstr: Option<String>bstr: Option<String>date: Option<String>file_time: Option<String>bool: Option<bool>cy: Option<String>error: Option<String>stream: Option<String>ostream: Option<String>storage: Option<String>ostorage: Option<String>vstream: Option<String>cls_id: Option<String>