Module decode_drawing

Module decode_drawing 

Decode-only drawing part helpers (xl/drawings/drawingN.xml).

Ported from Go xmlDecodeDrawing.go.

Structs

DecodeBlip
Specifies the existence of an image (binary large image or picture) and contains a reference to the image data.
DecodeBlipFill
Directly maps the blipFill (Picture Fill). This element specifies the kind of picture fill that the picture object has.
DecodeCNvPicPr
Directly maps the cNvPicPr (Non-Visual Picture Drawing Properties). This element specifies the non-visual properties for the picture canvas.
DecodeCNvPr
Directly maps the cNvPr (Non-Visual Drawing Properties). This element specifies non-visual canvas properties.
DecodeCNvSpPr
Connection Non-Visual Shape Properties. This element specifies the set of non-visual properties for a connection shape.
DecodeCellAnchor
Directly maps the oneCellAnchor (One Cell Anchor Shape Size) and twoCellAnchor (Two Cell Anchor Shape Size). This element specifies a two cell anchor placeholder for a group, a shape, or a drawing element. It moves with cells and its extents are in EMU units.
DecodeCellAnchorPos
Defines the structure used to deserialize the cell anchor for adjust drawing object on inserting/deleting column/rows.
DecodeCellImage
Defines the structure used to deserialize the Kingsoft WPS Office embedded cell images.
DecodeCellImages
Directly maps the Kingsoft WPS Office embedded cell images.
DecodeChoice
Defines the structure used to deserialize the mc:Choice element.
DecodeClientData
Directly maps the clientData element. An empty element which specifies (via attributes) certain properties related to printing and selection of the drawing object.
DecodeFrom
Specifies the starting anchor.
DecodeGraphicFrame
Defines the structure used to deserialize the xdr:graphicFrame element.
DecodeHlinkClick
Directly maps the hlinkClick (Hyperlink Click). This element specifies the on-click hyperlink information to be applied to a run of text. When the hyperlink text is clicked the link is fetched.
DecodeNvGraphicFramePr
Defines the structure used to deserialize the xdr:nvGraphicFramePr element.
DecodeNvPicPr
Directly maps the nvPicPr (Non-Visual Properties for a Picture). This element specifies all non-visual properties for a picture.
DecodeNvSpPr
Non-Visual Properties for a Shape. This element specifies all non-visual properties for a shape.
DecodeOff
Directly maps the colOff and rowOff element. This element is used to specify the column offset within a cell.
DecodePic
Encompass the definition of pictures within the DrawingML framework. While pictures are in many ways very similar to shapes they have specific properties that are unique in order to optimize for picture-specific scenarios.
DecodePicLocks
Directly maps the picLocks (Picture Locks). This element specifies all locking properties for a graphic frame.
DecodePositiveSize2D
Directly maps the a:ext element.
DecodePrstGeom
Directly maps the prstGeom (Preset geometry). This element specifies when a preset geometric shape should be used instead of a custom geometric shape.
DecodeSp
Defines the structure used to deserialize the sp element.
DecodeSpPr
Directly maps the spPr (Shape Properties). This element specifies the visual shape properties that can be applied to a picture.
DecodeStretch
Directly maps the stretch element. This element specifies that a BLIP should be stretched to fill the target rectangle.
DecodeTo
Directly specifies the ending anchor.
DecodeWsDr
Directly maps the root element for a part of this content type shall wsDr. In order to solve the problem that the label structure is changed after serialization and deserialization, two different structures are defined. DecodeWsDr is just for deserialization.
DecodeXfrm
Directly maps the xfrm (2D Transform for Graphic Frame). This element specifies the transform to be applied to the corresponding graphic frame.
XlsxAlternateContent
Container for a sequence of multiple representations of a given piece of content. The program reading the file should only process one of these, and the one chosen should be based on which conditions match.
XlsxFrom
Specifies the starting anchor (drawing variant).
XlsxPositiveSize2D
Directly maps the a:ext element (drawing variant).
XlsxSp
Shape. This element specifies the existence of a single shape.
XlsxTo
Directly specifies the ending anchor (drawing variant).