pub struct DecodePic {
pub nv_pic_pr: DecodeNvPicPr,
pub blip_fill: DecodeBlipFill,
pub sp_pr: DecodeSpPr,
}Expand description
Encompass the definition of pictures within the DrawingML framework. While pictures are in many ways very similar to shapes they have specific properties that are unique in order to optimize for picture-specific scenarios.
Fields
nv_pic_pr: DecodeNvPicPrblip_fill: DecodeBlipFillsp_pr: DecodeSpPrTrait Implementations
Sourceimpl<'de> Deserialize<'de> for DecodePic
impl<'de> Deserialize<'de> for DecodePic
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for DecodePic