pub struct DecodeWsDr {
pub a: String,
pub xdr: String,
pub r: String,
pub alternate_content: Vec<XlsxInnerXml>,
pub one_cell_anchor: Vec<DecodeCellAnchor>,
pub two_cell_anchor: Vec<DecodeCellAnchor>,
}Expand description
Directly maps the root element for a part of this content type shall wsDr.
In order to solve the problem that the label structure is changed after
serialization and deserialization, two different structures are defined.
DecodeWsDr is just for deserialization.
Fields
a: Stringxdr: Stringr: Stringalternate_content: Vec<XlsxInnerXml>one_cell_anchor: Vec<DecodeCellAnchor>two_cell_anchor: Vec<DecodeCellAnchor>Trait Implementations
Sourceimpl Clone for DecodeWsDr
impl Clone for DecodeWsDr
Sourcefn clone(&self) -> DecodeWsDr
fn clone(&self) -> DecodeWsDr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecodeWsDr
impl Debug for DecodeWsDr
Sourceimpl Default for DecodeWsDr
impl Default for DecodeWsDr
Sourcefn default() -> DecodeWsDr
fn default() -> DecodeWsDr
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DecodeWsDr
impl<'de> Deserialize<'de> for DecodeWsDr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DecodeWsDr
impl PartialEq for DecodeWsDr
Sourceimpl Serialize for DecodeWsDr
impl Serialize for DecodeWsDr
impl StructuralPartialEq for DecodeWsDr