Module metadata

Module metadata 

Metadata and rich value parts (xl/metadata.xml, xl/richData/).

Ported from Go xmlMetaData.go.

Structs

XlsxExternalReference
Directly maps the externalReference element of the external workbook references part.
XlsxFutureMetadata
Directly maps the futureMetadata element. This element represents future metadata information.
XlsxFutureMetadataBlock
Directly maps the bk element. This element represents a block of future metadata information. This is a location for storing feature extension information.
XlsxMetadata
Directly maps the metadata element. A cell in a spreadsheet application can have metadata associated with it. Metadata is just a set of additional properties about the particular cell, and this metadata is stored in the metadata xml part. There are two types of metadata: cell metadata and value metadata.
XlsxMetadataBlock
Directly maps the bk element. This element represents a block of metadata records.
XlsxMetadataBlocks
Directly maps the metadata element. This element represents cell metadata information. Cell metadata is information metadata about a specific cell, and it stays tied to that cell position.
XlsxMetadataRecord
Directly maps the rc element. This element represents a reference to a specific metadata record.
XlsxRichValue
Directly maps the rv element that specifies rich value data information for a single rich value.
XlsxRichValueData
Directly maps the rvData element that specifies rich value data.
XlsxRichValueKey
Directly maps the k element. This element specifies the rich value key.
XlsxRichValueRelRelationship
Directly maps the rel element. This element specifies a relationship for a rich value property.
XlsxRichValueRels
Directly maps the richValueRels element. This element specifies a list of rich value relationships.
XlsxRichValueStructure
Directly maps the s element. This element specifies the list of rich value structures.
XlsxRichValueStructures
Directly maps the rvStructures element. This element specifies rich value structures, which contain lists of rich value keys and the data types for the corresponding rich value data.
XlsxWebImageSupportingRichData
Directly maps the webImageSrd element. This element specifies a set of properties for a web image rich value.
XlsxWebImagesSupportingRichData
Directly maps the webImagesSrd element. This element specifies a list of sets of properties associated with web image rich values.