pub struct XlsxMetadata {
pub metadata_types: Option<XlsxInnerXml>,
pub metadata_strings: Option<XlsxInnerXml>,
pub mdx_metadata: Option<XlsxInnerXml>,
pub future_metadata: Vec<XlsxFutureMetadata>,
pub cell_metadata: Option<XlsxMetadataBlocks>,
pub value_metadata: Option<XlsxMetadataBlocks>,
pub ext_lst: Option<XlsxInnerXml>,
}Expand description
Directly maps the metadata element. A cell in a spreadsheet application can have metadata associated with it. Metadata is just a set of additional properties about the particular cell, and this metadata is stored in the metadata xml part. There are two types of metadata: cell metadata and value metadata.
Fields
metadata_types: Option<XlsxInnerXml>metadata_strings: Option<XlsxInnerXml>mdx_metadata: Option<XlsxInnerXml>future_metadata: Vec<XlsxFutureMetadata>cell_metadata: Option<XlsxMetadataBlocks>value_metadata: Option<XlsxMetadataBlocks>ext_lst: Option<XlsxInnerXml>Trait Implementations
Sourceimpl Clone for XlsxMetadata
impl Clone for XlsxMetadata
Sourcefn clone(&self) -> XlsxMetadata
fn clone(&self) -> XlsxMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxMetadata
impl Debug for XlsxMetadata
Sourceimpl Default for XlsxMetadata
impl Default for XlsxMetadata
Sourcefn default() -> XlsxMetadata
fn default() -> XlsxMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxMetadata
impl<'de> Deserialize<'de> for XlsxMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for XlsxMetadata
Sourceimpl PartialEq for XlsxMetadata
impl PartialEq for XlsxMetadata
Sourceimpl Serialize for XlsxMetadata
impl Serialize for XlsxMetadata
impl StructuralPartialEq for XlsxMetadata