pub struct XlsxMetadataBlocks {
pub count: Option<i64>,
pub bk: Vec<XlsxMetadataBlock>,
}Expand description
Directly maps the metadata element. This element represents cell metadata information. Cell metadata is information metadata about a specific cell, and it stays tied to that cell position.
Fields
count: Option<i64>bk: Vec<XlsxMetadataBlock>Trait Implementations
Sourceimpl Clone for XlsxMetadataBlocks
impl Clone for XlsxMetadataBlocks
Sourcefn clone(&self) -> XlsxMetadataBlocks
fn clone(&self) -> XlsxMetadataBlocks
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxMetadataBlocks
impl Debug for XlsxMetadataBlocks
Sourceimpl Default for XlsxMetadataBlocks
impl Default for XlsxMetadataBlocks
Sourcefn default() -> XlsxMetadataBlocks
fn default() -> XlsxMetadataBlocks
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxMetadataBlocks
impl<'de> Deserialize<'de> for XlsxMetadataBlocks
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for XlsxMetadataBlocks
Sourceimpl PartialEq for XlsxMetadataBlocks
impl PartialEq for XlsxMetadataBlocks
Sourceimpl Serialize for XlsxMetadataBlocks
impl Serialize for XlsxMetadataBlocks
impl StructuralPartialEq for XlsxMetadataBlocks