pub struct XlsxRichValueStructures {
pub count: Option<i64>,
pub s: Vec<XlsxRichValueStructure>,
pub ext_lst: Option<XlsxInnerXml>,
}Expand description
Directly maps the rvStructures element. This element specifies rich value structures, which contain lists of rich value keys and the data types for the corresponding rich value data.
Fields
count: Option<i64>s: Vec<XlsxRichValueStructure>ext_lst: Option<XlsxInnerXml>Trait Implementations
Sourceimpl Clone for XlsxRichValueStructures
impl Clone for XlsxRichValueStructures
Sourcefn clone(&self) -> XlsxRichValueStructures
fn clone(&self) -> XlsxRichValueStructures
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxRichValueStructures
impl Debug for XlsxRichValueStructures
Sourceimpl Default for XlsxRichValueStructures
impl Default for XlsxRichValueStructures
Sourcefn default() -> XlsxRichValueStructures
fn default() -> XlsxRichValueStructures
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxRichValueStructures
impl<'de> Deserialize<'de> for XlsxRichValueStructures
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for XlsxRichValueStructures
Sourceimpl PartialEq for XlsxRichValueStructures
impl PartialEq for XlsxRichValueStructures
Sourceimpl Serialize for XlsxRichValueStructures
impl Serialize for XlsxRichValueStructures
impl StructuralPartialEq for XlsxRichValueStructures