Module pivot_cache

Module pivot_cache 

Pivot cache definition part (xl/pivotCache/pivotCacheDefinitionN.xml).

Ported from Go xmlPivotCache.go.

Structs

DecodeX14PivotCacheDefinition
Structure used to parse the x14:pivotCacheDefinition element without the prefix.
XlsxCacheField
Single field in the PivotCache.
XlsxCacheFields
Collection of field definitions in the source data.
XlsxCacheHierarchies
Collection of OLAP hierarchies in the PivotCache.
XlsxCacheSource
Description of the data source whose data is stored in the pivot cache.
XlsxCalculatedItems
Collection of calculated items.
XlsxCalculatedMembers
Collection of calculated members in an OLAP PivotTable.
XlsxConsolidation
Description of the PivotCache source using multiple consolidation ranges.
XlsxDimensions
Collection of PivotTable OLAP dimensions.
XlsxFieldGroup
Collection of properties for a field group.
XlsxKpis
Collection of Key Performance Indicators defined on the OLAP server.
XlsxMaps
PivotTable OLAP measure group - Dimension maps.
XlsxMeasureGroups
Collection of PivotTable OLAP measure groups.
XlsxPivotCacheDefinition
Directly maps the pivotCacheDefinition element.
XlsxSharedItemData
Attributes and child elements shared by all shared item variants.
XlsxSharedItems
Collection of unique items for a field in the PivotCacheDefinition.
XlsxTupleCache
Cache of OLAP sheet data members, or tuples.
XlsxTuples
Members for the OLAP sheet data entry, also known as a tuple.
XlsxWorksheetSource
Location of the source of the data stored in the cache.
XlsxX
Index reference used by mpMap and pivot table items.
XlsxX14PivotCacheDefinition
Extended properties of a pivot table cache definition (x14:pivotCacheDefinition).

Enums

XlsxSharedItem
A shared item in the pivot table cache field.