Module pivot_table

Module pivot_table 

PivotTable definition part (xl/pivotTables/pivotTableN.xml).

Ported from Go xmlPivotTable.go.

Structs

DecodeX14DataField
Defines the structure used to parse the x14:dataField element of the pivot table data field.
XlsxAutoSortScope
Represents the sorting scope for the PivotTable.
XlsxColFields
Represents the collection of fields on the column axis of the PivotTable.
XlsxColItems
Represents the collection of column items of the PivotTable.
XlsxConditionalFormats
Represents the collection of conditional formats applied to a PivotTable.
XlsxDataField
Represents a field that contains data summarized in a PivotTable.
XlsxDataFields
Represents the collection of items in the data region of the PivotTable.
XlsxField
Represents a generic field that can appear on the column or row region.
XlsxI
Represents the collection of items in the row region of the PivotTable.
XlsxItem
Represents a single item in a PivotTable field.
XlsxItems
Represents the collection of items in a PivotTable field.
XlsxLocation
Represents location information for the PivotTable.
XlsxPageField
Represents a field on the page or report filter of the PivotTable.
XlsxPageFields
Represents the collection of items in the page or report filter region.
XlsxPivotField
Represents a single field in the PivotTable.
XlsxPivotFields
Represents the collection of fields that appear on the PivotTable.
XlsxPivotTableDefinition
Directly maps the pivotTableDefinition root element.
XlsxPivotTableStyleInfo
Represents information on style applied to the PivotTable.
XlsxRowFields
Represents the collection of row fields for the PivotTable.
XlsxRowItems
Represents the collection of items in the row axis of the PivotTable.
XlsxX
Represents an array of indexes to cached shared item values.
XlsxX14DataField
Specifies extended information about a data field in the pivot table.