pub struct XlsxTimelines {
pub xmlns_mc: Option<String>,
pub xmlns_x: Option<String>,
pub xmlns_xr10: Option<String>,
pub timeline: Vec<XlsxTimeline>,
}Expand description
A mechanism for filtering data in pivot table views, cube functions and charts based on non-worksheet pivot tables. In the case of using OLAP Timeline source data, a Timeline is based on a key attribute of an OLAP hierarchy. In the case of using native Timeline source data, a Timeline is based on a data table column.
Fields
xmlns_mc: Option<String>xmlns_x: Option<String>xmlns_xr10: Option<String>timeline: Vec<XlsxTimeline>Trait Implementations
Sourceimpl Clone for XlsxTimelines
impl Clone for XlsxTimelines
Sourcefn clone(&self) -> XlsxTimelines
fn clone(&self) -> XlsxTimelines
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxTimelines
impl Debug for XlsxTimelines
Sourceimpl Default for XlsxTimelines
impl Default for XlsxTimelines
Sourcefn default() -> XlsxTimelines
fn default() -> XlsxTimelines
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxTimelines
impl<'de> Deserialize<'de> for XlsxTimelines
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxTimelines
impl PartialEq for XlsxTimelines
Sourceimpl Serialize for XlsxTimelines
impl Serialize for XlsxTimelines
impl StructuralPartialEq for XlsxTimelines