Module styles

Module styles 

Styles part (xl/styles.xml).

Ported from Go xmlStyles.go.

Structs

XlsxAlignment
Formatting information pertaining to text alignment in cells.
XlsxBorder
A single set of cell border formats.
XlsxBorders
Directly maps the borders element.
XlsxCellStyle
A named cell style.
XlsxCellStyleXfs
Directly maps the cellStyleXfs element.
XlsxCellStyles
Directly maps the cellStyles element.
XlsxCellXfs
Directly maps the cellXfs element.
XlsxDxf
A single dxf record expressing incremental formatting.
XlsxDxfs
Directly maps the dxfs element.
XlsxFill
Directly maps the fill element.
XlsxFills
Directly maps the fills element.
XlsxFont
Directly maps the font element.
XlsxFonts
Directly maps the fonts element.
XlsxGradientFill
A gradient-style cell fill.
XlsxGradientFillStop
A single gradient stop.
XlsxIndexedColors
A single ARGB entry for the corresponding color index.
XlsxLine
A single set of cell border.
XlsxNumFmt
Directly maps the numFmt element.
XlsxNumFmts
Directly maps the numFmts element.
XlsxPatternFill
Cell fill information for pattern and solid color cell fills.
XlsxProtection
Protection properties associated with a cell.
XlsxStyleColors
Color information associated with the style sheet.
XlsxStyleSheet
Directly maps the root element of the Styles part.
XlsxTableStyle
A single table style definition.
XlsxTableStyles
Directly maps the tableStyles element.
XlsxXf
A single xf element describing all formatting for a cell.