Table part (xl/tables/table*.xml).
Ported from Go xmlTable.go.
Structs
- Auto
Filter Options - Directly maps the auto filter settings.
- Table
- Directly maps the format settings of the table.
- Xlsx
Auto Filter - Temporarily hides rows based on a filter criteria, which is applied column by column to a table of data in the worksheet.
- Xlsx
Color Filter - Specifies the color to filter by and whether to use the cell’s fill or font color in the filter criteria.
- Xlsx
Custom Filter - A custom AutoFilter specifies an operator and a value.
- Xlsx
Custom Filters - Groups custom filter elements together when there is more than one custom filter criteria to apply.
- Xlsx
Date Group Item - Expresses a group of dates or times which are used in an AutoFilter criteria.
- Xlsx
Dynamic Filter - Specifies dynamic filter criteria. These criteria can change either with the data itself or with the current system date.
- Xlsx
Filter - Expresses a filter criteria value.
- Xlsx
Filter Column - Identifies a particular column in the AutoFilter range and specifies filter information that has been applied to this column.
- Xlsx
Filters - Groups filter criteria together when multiple values are chosen to filter by, or when a group of date values are chosen to filter by.
- Xlsx
Icon Filter - Specifies the icon set and particular icon within that set to filter by.
- Xlsx
Single XmlCell - Represents the table properties for a single cell XML table.
- Xlsx
Single XmlCells - A single cell table generated from an XML mapping.
- Xlsx
Table - Directly maps the table element. A table helps organize and provide structure to list of information in a worksheet.
- Xlsx
Table Column - Represents a single column for this table.
- Xlsx
Table Columns - Represents the collection of all table columns for this table.
- Xlsx
Table Style Info - Describes which style is used to display this table, and specifies which portions of the table have the style applied.
- Xlsx
Top10 - Specifies the top N (percent or number of items) to filter by.
- Xlsx
XmlCell Pr - Stores the XML properties for the cell of a single cell xml table.