pub struct XlsxAutoFilter {
pub ref: String,
pub filter_column: Vec<XlsxFilterColumn>,
}Expand description
Temporarily hides rows based on a filter criteria, which is applied column by column to a table of data in the worksheet.
Fields
ref: Stringfilter_column: Vec<XlsxFilterColumn>Trait Implementations
Sourceimpl Clone for XlsxAutoFilter
impl Clone for XlsxAutoFilter
Sourcefn clone(&self) -> XlsxAutoFilter
fn clone(&self) -> XlsxAutoFilter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxAutoFilter
impl Debug for XlsxAutoFilter
Sourceimpl Default for XlsxAutoFilter
impl Default for XlsxAutoFilter
Sourcefn default() -> XlsxAutoFilter
fn default() -> XlsxAutoFilter
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxAutoFilter
impl<'de> Deserialize<'de> for XlsxAutoFilter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxAutoFilter
impl PartialEq for XlsxAutoFilter
Sourceimpl Serialize for XlsxAutoFilter
impl Serialize for XlsxAutoFilter
impl StructuralPartialEq for XlsxAutoFilter