pub struct XlsxFilters {
pub blank: bool,
pub calendar_type: Option<String>,
pub filter: Vec<XlsxFilter>,
pub date_group_item: Vec<XlsxDateGroupItem>,
}Expand description
Groups filter criteria together when multiple values are chosen to filter by, or when a group of date values are chosen to filter by.
Fields
blank: boolcalendar_type: Option<String>filter: Vec<XlsxFilter>date_group_item: Vec<XlsxDateGroupItem>Trait Implementations
Sourceimpl Clone for XlsxFilters
impl Clone for XlsxFilters
Sourcefn clone(&self) -> XlsxFilters
fn clone(&self) -> XlsxFilters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxFilters
impl Debug for XlsxFilters
Sourceimpl Default for XlsxFilters
impl Default for XlsxFilters
Sourcefn default() -> XlsxFilters
fn default() -> XlsxFilters
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxFilters
impl<'de> Deserialize<'de> for XlsxFilters
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxFilters
impl PartialEq for XlsxFilters
Sourceimpl Serialize for XlsxFilters
impl Serialize for XlsxFilters
impl StructuralPartialEq for XlsxFilters