pub struct XlsxTableStyleInfo {
pub name: Option<String>,
pub show_first_column: bool,
pub show_last_column: bool,
pub show_row_stripes: bool,
pub show_column_stripes: bool,
}Expand description
Describes which style is used to display this table, and specifies which portions of the table have the style applied.
Fields
name: Option<String>show_first_column: boolshow_last_column: boolshow_row_stripes: boolshow_column_stripes: boolTrait Implementations
Sourceimpl Clone for XlsxTableStyleInfo
impl Clone for XlsxTableStyleInfo
Sourcefn clone(&self) -> XlsxTableStyleInfo
fn clone(&self) -> XlsxTableStyleInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxTableStyleInfo
impl Debug for XlsxTableStyleInfo
Sourceimpl Default for XlsxTableStyleInfo
impl Default for XlsxTableStyleInfo
Sourcefn default() -> XlsxTableStyleInfo
fn default() -> XlsxTableStyleInfo
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxTableStyleInfo
impl<'de> Deserialize<'de> for XlsxTableStyleInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxTableStyleInfo
impl PartialEq for XlsxTableStyleInfo
Sourceimpl Serialize for XlsxTableStyleInfo
impl Serialize for XlsxTableStyleInfo
impl StructuralPartialEq for XlsxTableStyleInfo