Module theme

Module theme 

Theme part (xl/theme/themeN.xml).

Ported from Go xmlTheme.go.

Structs

DecodeBaseStyles
Deserialization-only representation of the theme elements.
DecodeColorScheme
Deserialization-only representation of a set of colors for the theme.
DecodeCtColor
Deserialization-only representation of the actual color values.
DecodeFontCollection
Deserialization-only representation of a major and minor font collection.
DecodeFontScheme
Deserialization-only representation of the font scheme within the theme.
DecodeStyleMatrix
Deserialization-only representation of a set of formatting options.
DecodeTheme
Deserialization-only representation of the theme element.
XlsxBaseStyles
Defines the theme elements for a theme, and is the workhorse of the theme.
XlsxColorScheme
Defines a set of colors for the theme.
XlsxCtColor
Holds the actual color values that are to be applied to a given diagram and how those colors are to be applied.
XlsxCtSupplementalFont
Defines an additional font that is used for language specific fonts in themes.
XlsxCtTextFont
Defines a text font properties used by theme font collections.
XlsxFontCollection
Defines a major and minor font which is used in the font scheme.
XlsxFontScheme
Defines the font scheme within the theme.
XlsxStyleMatrix
Defines a set of formatting options, which can be referenced by documents that apply a certain style to a given part of an object.
XlsxSysClr
Specifies a color bound to predefined operating system elements.
XlsxTheme
Directly maps the theme element in the namespace http://schemas.openxmlformats.org/drawingml/2006/main.