pub struct XlsxCtColor {
pub scrgb_clr: Option<XlsxInnerXml>,
pub srgb_clr: Option<AttrValString>,
pub hsl_clr: Option<XlsxInnerXml>,
pub sys_clr: Option<XlsxSysClr>,
pub scheme_clr: Option<XlsxInnerXml>,
pub prst_clr: Option<XlsxInnerXml>,
}Expand description
Holds the actual color values that are to be applied to a given diagram and how those colors are to be applied.
Fields
scrgb_clr: Option<XlsxInnerXml>srgb_clr: Option<AttrValString>hsl_clr: Option<XlsxInnerXml>sys_clr: Option<XlsxSysClr>scheme_clr: Option<XlsxInnerXml>prst_clr: Option<XlsxInnerXml>Trait Implementations
Sourceimpl Clone for XlsxCtColor
impl Clone for XlsxCtColor
Sourcefn clone(&self) -> XlsxCtColor
fn clone(&self) -> XlsxCtColor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxCtColor
impl Debug for XlsxCtColor
Sourceimpl Default for XlsxCtColor
impl Default for XlsxCtColor
Sourcefn default() -> XlsxCtColor
fn default() -> XlsxCtColor
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxCtColor
impl<'de> Deserialize<'de> for XlsxCtColor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxCtColor
impl PartialEq for XlsxCtColor
Sourceimpl Serialize for XlsxCtColor
impl Serialize for XlsxCtColor
impl StructuralPartialEq for XlsxCtColor