pub struct XlsxStyleMatrix {
pub name: Option<String>,
pub fill_style_lst: XlsxInnerXml,
pub ln_style_lst: XlsxInnerXml,
pub effect_style_lst: XlsxInnerXml,
pub bg_fill_style_lst: XlsxInnerXml,
}Expand description
Defines a set of formatting options, which can be referenced by documents that apply a certain style to a given part of an object.
Fields
name: Option<String>fill_style_lst: XlsxInnerXmlln_style_lst: XlsxInnerXmleffect_style_lst: XlsxInnerXmlbg_fill_style_lst: XlsxInnerXmlTrait Implementations
Sourceimpl Clone for XlsxStyleMatrix
impl Clone for XlsxStyleMatrix
Sourcefn clone(&self) -> XlsxStyleMatrix
fn clone(&self) -> XlsxStyleMatrix
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for XlsxStyleMatrix
impl Debug for XlsxStyleMatrix
Sourceimpl Default for XlsxStyleMatrix
impl Default for XlsxStyleMatrix
Sourcefn default() -> XlsxStyleMatrix
fn default() -> XlsxStyleMatrix
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for XlsxStyleMatrix
impl<'de> Deserialize<'de> for XlsxStyleMatrix
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for XlsxStyleMatrix
impl PartialEq for XlsxStyleMatrix
Sourceimpl Serialize for XlsxStyleMatrix
impl Serialize for XlsxStyleMatrix
impl StructuralPartialEq for XlsxStyleMatrix