pub struct DataValidation {Show 14 fields
pub allow_blank: bool,
pub error: Option<String>,
pub error_style: Option<String>,
pub error_title: Option<String>,
pub operator: String,
pub prompt: Option<String>,
pub prompt_title: Option<String>,
pub show_drop_down: bool,
pub show_error_message: bool,
pub show_input_message: bool,
pub sqref: String,
pub type: String,
pub formula1: String,
pub formula2: String,
}Expand description
Data validation rule settings.
Fields
allow_blank: boolerror: Option<String>error_style: Option<String>error_title: Option<String>operator: Stringprompt: Option<String>prompt_title: Option<String>show_drop_down: boolshow_error_message: boolshow_input_message: boolsqref: Stringtype: Stringformula1: Stringformula2: StringImplementations
Sourceimpl DataValidation
impl DataValidation
Sourcepub fn set_error(
&mut self,
style: DataValidationErrorStyle,
title: &str,
msg: &str,
)
pub fn set_error( &mut self, style: DataValidationErrorStyle, title: &str, msg: &str, )
Set the error alert for this data validation rule.
Sourcepub fn set_input(&mut self, title: &str, msg: &str)
pub fn set_input(&mut self, title: &str, msg: &str)
Set the input prompt for this data validation rule.
Sourcepub fn set_drop_list(&mut self, keys: &[&str]) -> Result<()>
pub fn set_drop_list(&mut self, keys: &[&str]) -> Result<()>
Set a fixed drop-down list.
Sourcepub fn set_range(
&mut self,
f1: DataValidationValue,
f2: DataValidationValue,
t: DataValidationType,
o: DataValidationOperator,
) -> Result<()>
pub fn set_range( &mut self, f1: DataValidationValue, f2: DataValidationValue, t: DataValidationType, o: DataValidationOperator, ) -> Result<()>
Set a numeric range validation.
Sourcepub fn set_sqref_drop_list(&mut self, sqref: &str)
pub fn set_sqref_drop_list(&mut self, sqref: &str)
Set a drop-down list backed by a worksheet range reference.