Row/column adjustment helpers.
This module corresponds to adjust.go in the Go implementation. It updates
cell references, formulas, merged cells, auto filters, tables, hyperlinks,
conditional formats, data validations and the calculation chain when rows or
columns are inserted or deleted.
Enums
- Adjust
Direction - Direction of the adjustment operation.