Workbook encryption / decryption (crypt.go).
Provides ECMA-376 agile and standard encryption helpers, CFB packaging and the ISO password hashing algorithm used for sheet/workbook protection.
Structs
- Data
Integrity - Encrypted copies of the salt/hash values used for integrity checks.
- Encrypted
Key - Encrypted key used to derive the package encryption key.
- Encryption
- Top-level encryption info container used by ECMA-376 agile encryption.
- KeyData
- Cryptographic attributes used to encrypt the data.
- KeyEncryptor
- A single key encryptor entry.
- KeyEncryptors
- Collection of key encryptors.
- Standard
Encryption Header - Standard
Encryption Verifier
Functions
- decrypt
- Decrypt a CFB-encoded workbook package.
- encrypt
- Encrypt a workbook package with a password using ECMA-376 standard encryption (AES-128).
- gen_
iso_ passwd_ hash - Generate an ISO password hash, salt and hash value.