Number format parser and applier.
Ports the most commonly used parts of Go numfmt.go. It maps built-in
number-format IDs to their format strings and can apply many custom format
codes for numbers, percentages, scientific notation, fractions, currency,
accounting, dates and times.
Statics
- BUILT_
IN_ NUM_ FMT - Built-in number format map (English localization).
Functions
- apply_
number_ format - Apply a number format to a numeric value.
- built_
in_ num_ fmt_ code - Return the built-in format code for an ID, if one exists.
- format_
number - Apply a format code directly to a numeric value without an Excel numFmt ID.
- is_
date_ time_ pattern - Check whether a number-format pattern is suitable for use as a date/time pattern.