Streaming writer API.
Ported from Go stream.go.
Structs
- Cell
- Cell value used by the streaming writer to carry a per-cell style or formula.
- RowOpts
- Row formatting options used by
StreamWriter::set_row. - Stream
Cell - Internal representation of a value to be written by the streaming writer.
- Stream
Writer - Streaming writer for worksheets with large amounts of data.
Traits
- Stream
Cell Value - Values that can be passed to
StreamWriter::set_row.