Module chart

Module chart 

Chart part (xl/charts/chartN.xml).

Ported from Go xmlChart.go.

Structs

AContourClr
Directly maps the a:contourClr element. This element defines the color for the contour on a shape.
ASp3D
Directly maps the a:sp3d element. This element defines the 3D properties associated with a particular shape in DrawingML.
CAutoTitleDeleted
Directly maps the autoTitleDeleted element. This element specifies the title shall not be shown for this chart.
CAxs
Directly maps the catAx and valAx element.
CCat
Directly maps the cat element. This element specifies the data used for the category axis.
CChart
Directly maps the chart element. This element specifies a title.
CCharts
Specifies the common element of the chart.
CDLbls
Directly maps the dLbls element. This element serves as a root element that specifies the settings for the data labels for an entire series or the entire chart.
CDPt
Directly maps the dPt element. This element specifies a single data point.
CDTable
Directly maps the dTable element.
CLayout
Directly maps the layout element. This element specifies how the chart element is placed on the chart.
CLegend
Directly maps the legend element. This element specifies the legend.
CLegendEntry
Directly maps the legendEntry element. This element specifies the legend entry.
CLines
Directly maps the chart lines content model.
CManualLayout
Directly maps the manualLayout element. This element specifies the exact position of a chart element.
CMarker
Directly maps the marker element. This element specifies a data marker.
CNumCache
Directly maps the numCache element. This element specifies the last data shown on the chart for a series.
CNumFmt
Directly maps the numFmt element. This element specifies number formatting for the parent element.
CNumRef
Directly maps the numRef element. This element specifies a reference to numeric data with a cache of the last values used.
CPageMargins
Directly maps the pageMargins element. This element specifies the page margins for a chart.
CPlotArea
Directly maps the plotArea element. This element specifies the plot area of the chart.
CPrintSettings
Directly maps the printSettings element. This element specifies the print settings for the chart.
CPt
Directly maps the pt element. This element specifies data for a particular data point.
CRich
Directly maps the rich element. This element contains a string with rich text formatting.
CScaling
Directly maps the scaling element. This element contains additional axis settings.
CSer
Directly maps the ser element. This element specifies a series on a chart.
CSpPr
Directly maps the spPr element. This element specifies the visual shape properties that can be applied to a shape. These properties include the shape fill, outline, geometry, effects, and 3D orientation.
CStrCache
Directly maps the strCache element. This element specifies the last string data used for a chart.
CStrRef
Directly maps the strRef element. This element specifies a reference to data for a single data label or title with a cache of the last values used.
CThicknessSpPr
Directly maps the element that specifies the thickness of the walls or floor as a percentage of the largest dimension of the plot volume and SpPr element.
CTitle
Directly maps the title element. This element specifies a title.
CTx
Directly maps the tx element. This element specifies text to use on a chart, including rich text formatting.
CTxPr
Directly maps the txPr element. This element specifies text formatting. The lstStyle element is not supported.
CUpDownBars
Directly maps the upDownBars element. This element specifies the up and down bars.
CVal
Directly maps the val element. This element specifies the data values which shall be used to define the location of data markers on a chart.
CView3D
Directly maps the view3D element. This element specifies the 3-D view of the chart.
Chart
Directly maps the format settings of the chart.
ChartAxis
Directly maps the format settings of the chart axis.
ChartDataLabel
Directly maps the format settings of the chart labels.
ChartDataLabelPositionType
Type of chart data labels position.
ChartDataPoint
Directly maps the format settings of the chart data point for doughnut, pie and 3D pie charts.
ChartDimension
Directly maps the dimension of the chart.
ChartLegend
Directly maps the format settings of the chart legend.
ChartMarker
Directly maps the format settings of the chart marker.
ChartNumFmt
Directly maps the number format settings of the chart.
ChartPlotArea
Directly maps the format settings of the plot area.
ChartSeries
Directly maps the format settings of the chart series.
ChartTickLabelPositionType
Type of supported chart tick label position types.
ChartTitle
Directly maps the format settings of the chart title.
ChartType
Type of supported chart types.
ChartUpDownBar
Directly maps the format settings of the stock chart up bars and down bars.
XlsxChartSpace
Directly maps the chartSpace element. The chart namespace in DrawingML is for representing visualizations of numeric data with column charts, pie charts, scatter charts, or other types of charts.