Custom file properties part (docProps/custom.xml).
Ported from Go xmlCustom.go.
Structs
- Custom
Property - Directly maps the custom property of the workbook. The value date type may be one of the following: int32, float64, string, bool, time.Time, or nil.
- Decode
Custom Properties - Deserialization-only representation of the custom file properties part.
- Decode
Property - Deserialization-only representation of a single custom file property.
- Xlsx
Custom Properties - Directly maps the element for the custom file properties part, that represents additional information. The information can be used as metadata for XML.
- Xlsx
Property - Directly maps the element specifies a single custom file property. Custom file property type is defined through child elements in the File Properties Variant Type namespace. Custom file property value can be set by setting the appropriate Variant Type child element value.
Enums
- Custom
Property Value - Value types that can be stored in a custom property.