Decode-only drawing part helpers (xl/drawings/drawingN.xml).
Ported from Go xmlDecodeDrawing.go.
Structs
- Decode
Blip - Specifies the existence of an image (binary large image or picture) and contains a reference to the image data.
- Decode
Blip Fill - Directly maps the
blipFill(Picture Fill). This element specifies the kind of picture fill that the picture object has. - DecodeC
NvPic Pr - Directly maps the
cNvPicPr(Non-Visual Picture Drawing Properties). This element specifies the non-visual properties for the picture canvas. - DecodeC
NvPr - Directly maps the
cNvPr(Non-Visual Drawing Properties). This element specifies non-visual canvas properties. - DecodeC
NvSp Pr - Connection Non-Visual Shape Properties. This element specifies the set of non-visual properties for a connection shape.
- Decode
Cell Anchor - Directly maps the
oneCellAnchor(One Cell Anchor Shape Size) andtwoCellAnchor(Two Cell Anchor Shape Size). This element specifies a two cell anchor placeholder for a group, a shape, or a drawing element. It moves with cells and its extents are in EMU units. - Decode
Cell Anchor Pos - Defines the structure used to deserialize the cell anchor for adjust drawing object on inserting/deleting column/rows.
- Decode
Cell Image - Defines the structure used to deserialize the Kingsoft WPS Office embedded cell images.
- Decode
Cell Images - Directly maps the Kingsoft WPS Office embedded cell images.
- Decode
Choice - Defines the structure used to deserialize the
mc:Choiceelement. - Decode
Client Data - Directly maps the
clientDataelement. An empty element which specifies (via attributes) certain properties related to printing and selection of the drawing object. - Decode
From - Specifies the starting anchor.
- Decode
Graphic Frame - Defines the structure used to deserialize the
xdr:graphicFrameelement. - Decode
Hlink Click - Directly maps the
hlinkClick(Hyperlink Click). This element specifies the on-click hyperlink information to be applied to a run of text. When the hyperlink text is clicked the link is fetched. - Decode
NvGraphic Frame Pr - Defines the structure used to deserialize the
xdr:nvGraphicFramePrelement. - Decode
NvPic Pr - Directly maps the
nvPicPr(Non-Visual Properties for a Picture). This element specifies all non-visual properties for a picture. - Decode
NvSp Pr - Non-Visual Properties for a Shape. This element specifies all non-visual properties for a shape.
- Decode
Off - Directly maps the
colOffandrowOffelement. This element is used to specify the column offset within a cell. - Decode
Pic - Encompass the definition of pictures within the DrawingML framework. While pictures are in many ways very similar to shapes they have specific properties that are unique in order to optimize for picture-specific scenarios.
- Decode
PicLocks - Directly maps the
picLocks(Picture Locks). This element specifies all locking properties for a graphic frame. - Decode
Positive Size2D - Directly maps the
a:extelement. - Decode
Prst Geom - Directly maps the
prstGeom(Preset geometry). This element specifies when a preset geometric shape should be used instead of a custom geometric shape. - Decode
Sp - Defines the structure used to deserialize the
spelement. - Decode
SpPr - Directly maps the
spPr(Shape Properties). This element specifies the visual shape properties that can be applied to a picture. - Decode
Stretch - Directly maps the
stretchelement. This element specifies that a BLIP should be stretched to fill the target rectangle. - Decode
To - Directly specifies the ending anchor.
- Decode
WsDr - Directly maps the root element for a part of this content type shall
wsDr. In order to solve the problem that the label structure is changed after serialization and deserialization, two different structures are defined.DecodeWsDris just for deserialization. - Decode
Xfrm - Directly maps the
xfrm(2D Transform for Graphic Frame). This element specifies the transform to be applied to the corresponding graphic frame. - Xlsx
Alternate Content - Container for a sequence of multiple representations of a given piece of content. The program reading the file should only process one of these, and the one chosen should be based on which conditions match.
- Xlsx
From - Specifies the starting anchor (drawing variant).
- Xlsx
Positive Size2D - Directly maps the
a:extelement (drawing variant). - XlsxSp
- Shape. This element specifies the existence of a single shape.
- XlsxTo
- Directly specifies the ending anchor (drawing variant).