DecodeWsDr

Struct DecodeWsDr 

pub struct DecodeWsDr {
    pub a: String,
    pub xdr: String,
    pub r: String,
    pub alternate_content: Vec<XlsxInnerXml>,
    pub one_cell_anchor: Vec<DecodeCellAnchor>,
    pub two_cell_anchor: Vec<DecodeCellAnchor>,
}
Directly maps the root element for a part of this content type shall wsDr. In order to solve the problem that the label structure is changed after serialization and deserialization, two different structures are defined. DecodeWsDr is just for deserialization.

Fields

a: Stringxdr: Stringr: Stringalternate_content: Vec<XlsxInnerXml>one_cell_anchor: Vec<DecodeCellAnchor>two_cell_anchor: Vec<DecodeCellAnchor>