Metadata and rich value parts (xl/metadata.xml, xl/richData/).
Ported from Go xmlMetaData.go.
Structs
- Xlsx
External Reference - Directly maps the externalReference element of the external workbook references part.
- Xlsx
Future Metadata - Directly maps the futureMetadata element. This element represents future metadata information.
- Xlsx
Future Metadata Block - Directly maps the bk element. This element represents a block of future metadata information. This is a location for storing feature extension information.
- Xlsx
Metadata - Directly maps the metadata element. A cell in a spreadsheet application can have metadata associated with it. Metadata is just a set of additional properties about the particular cell, and this metadata is stored in the metadata xml part. There are two types of metadata: cell metadata and value metadata.
- Xlsx
Metadata Block - Directly maps the bk element. This element represents a block of metadata records.
- Xlsx
Metadata Blocks - Directly maps the metadata element. This element represents cell metadata information. Cell metadata is information metadata about a specific cell, and it stays tied to that cell position.
- Xlsx
Metadata Record - Directly maps the rc element. This element represents a reference to a specific metadata record.
- Xlsx
Rich Value - Directly maps the rv element that specifies rich value data information for a single rich value.
- Xlsx
Rich Value Data - Directly maps the rvData element that specifies rich value data.
- Xlsx
Rich Value Key - Directly maps the k element. This element specifies the rich value key.
- Xlsx
Rich Value RelRelationship - Directly maps the rel element. This element specifies a relationship for a rich value property.
- Xlsx
Rich Value Rels - Directly maps the richValueRels element. This element specifies a list of rich value relationships.
- Xlsx
Rich Value Structure - Directly maps the s element. This element specifies the list of rich value structures.
- Xlsx
Rich Value Structures - Directly maps the rvStructures element. This element specifies rich value structures, which contain lists of rich value keys and the data types for the corresponding rich value data.
- Xlsx
WebImage Supporting Rich Data - Directly maps the webImageSrd element. This element specifies a set of properties for a web image rich value.
- Xlsx
WebImages Supporting Rich Data - Directly maps the webImagesSrd element. This element specifies a list of sets of properties associated with web image rich values.