Module table

Module table 

Table part (xl/tables/table*.xml).

Ported from Go xmlTable.go.

Structs

AutoFilterOptions
Directly maps the auto filter settings.
Table
Directly maps the format settings of the table.
XlsxAutoFilter
Temporarily hides rows based on a filter criteria, which is applied column by column to a table of data in the worksheet.
XlsxColorFilter
Specifies the color to filter by and whether to use the cell’s fill or font color in the filter criteria.
XlsxCustomFilter
A custom AutoFilter specifies an operator and a value.
XlsxCustomFilters
Groups custom filter elements together when there is more than one custom filter criteria to apply.
XlsxDateGroupItem
Expresses a group of dates or times which are used in an AutoFilter criteria.
XlsxDynamicFilter
Specifies dynamic filter criteria. These criteria can change either with the data itself or with the current system date.
XlsxFilter
Expresses a filter criteria value.
XlsxFilterColumn
Identifies a particular column in the AutoFilter range and specifies filter information that has been applied to this column.
XlsxFilters
Groups filter criteria together when multiple values are chosen to filter by, or when a group of date values are chosen to filter by.
XlsxIconFilter
Specifies the icon set and particular icon within that set to filter by.
XlsxSingleXmlCell
Represents the table properties for a single cell XML table.
XlsxSingleXmlCells
A single cell table generated from an XML mapping.
XlsxTable
Directly maps the table element. A table helps organize and provide structure to list of information in a worksheet.
XlsxTableColumn
Represents a single column for this table.
XlsxTableColumns
Represents the collection of all table columns for this table.
XlsxTableStyleInfo
Describes which style is used to display this table, and specifies which portions of the table have the style applied.
XlsxTop10
Specifies the top N (percent or number of items) to filter by.
XlsxXmlCellPr
Stores the XML properties for the cell of a single cell xml table.