Theme part (xl/theme/themeN.xml).
Ported from Go xmlTheme.go.
Structs
- Decode
Base Styles - Deserialization-only representation of the theme elements.
- Decode
Color Scheme - Deserialization-only representation of a set of colors for the theme.
- Decode
CtColor - Deserialization-only representation of the actual color values.
- Decode
Font Collection - Deserialization-only representation of a major and minor font collection.
- Decode
Font Scheme - Deserialization-only representation of the font scheme within the theme.
- Decode
Style Matrix - Deserialization-only representation of a set of formatting options.
- Decode
Theme - Deserialization-only representation of the
themeelement. - Xlsx
Base Styles - Defines the theme elements for a theme, and is the workhorse of the theme.
- Xlsx
Color Scheme - Defines a set of colors for the theme.
- Xlsx
CtColor - Holds the actual color values that are to be applied to a given diagram and how those colors are to be applied.
- Xlsx
CtSupplemental Font - Defines an additional font that is used for language specific fonts in themes.
- Xlsx
CtText Font - Defines a text font properties used by theme font collections.
- Xlsx
Font Collection - Defines a major and minor font which is used in the font scheme.
- Xlsx
Font Scheme - Defines the font scheme within the theme.
- Xlsx
Style Matrix - Defines a set of formatting options, which can be referenced by documents that apply a certain style to a given part of an object.
- Xlsx
SysClr - Specifies a color bound to predefined operating system elements.
- Xlsx
Theme - Directly maps the theme element in the namespace http://schemas.openxmlformats.org/drawingml/2006/main.